# dmdeeg
## Decomposing eeg data with dynamic mode decomposition (dmd)

This package is still in progress. It will help to apply dmd to neurophysiological data, with a focus on EEG data.

## We already applied DMD in the following papers:

- Goelz C, Mora K, Rudisch J, Gaidai R, Reuter E, Godde B, Reinsberger C, Voelcker-Rehage C, Vieluf S. Classification of visuomotor tasks based on electroencephalographic data depends on age-related differences in brain activity patterns. Neural Netw (2021). https://doi.org/10.1016/j.neunet.2021.04.029.

- Goelz, C., Mora, K., Stroehlein, J.K. et al. Electrophysiological signatures of dedifferentiation differ between fit and less fit older adults. Cogn Neurodyn (2021). https://doi.org/10.1007/s11571-020-09656-9

- Goelz C, Voelcker-Rehage C, Mora K, Reuter EM, Godde B, Dellnitz M, Reinsberger C, Vieluf S. Improved Neural Control of Movements Manifests in Expertise-Related Differences in Force Output and Brain Network Dynamics. Front Physiol. (2018). https://doi.org/10.3389/fphys.2018.01540.

- Vieluf S, Mora K, Goelz C, Reuter EM, Godde B, Dellnitz M, Reinsberger C, Voelcker-Rehage C. Age- and Expertise-Related Differences of Sensorimotor Network Dynamics during Force Control. Neuroscience. (2018). https://doi.org/10.1016/j.neuroscience.2018.07.025. 

## Implementation is based on 
- Brunton BW, Johnson LA, Ojemann JG, Kutz JN. Extracting spatial-temporal coherent patterns in large-scale neural recordings using dynamic mode decomposition. J Neurosci Methods. (2016). https://doi.org/10.1016/j.jneumeth.2015.10.010.

[Open points: 
- add tests 
- add installation instructions etc.
- add plotting (scalp maps)
- add examples
- show results of papers
]
